
// 
// Copyright (C)2003 by BonusData AG, 
// Tiergartenweg 1, CH-4710 Balsthal, Switzerland.
// -----------------------------------------------
// Phone:	+41 62 3919600 
// Fax:		+41 62 3919601
// E-Mail:  team@bonusdata.net
// WEB:		http://www.bonusdata.net
//------------------------------------------------ 

// MDBEngine.h : main header file for the MDBEngine DLL
//-----------------------------------------------------
#if !defined(AFX_MDBENGINE_H__D36C6134_7713_47CA_91D1_D9CD0CEC52EB__INCLUDED_)
#define AFX_MDBENGINE_H__D36C6134_7713_47CA_91D1_D9CD0CEC52EB__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "MDBDefines.h"
#include "EXEDefines.h"

// Implementation notes:
//----------------------
// The USB to MDB interface has two MDB connectors.
//
// ==> MDB master to address peripherals.
// Current implementation:
// - Debit Card Reader with calls like "Reader..."
// - Change Giver with calls like "Acceptor..."
// - Bill Acceptor with calls like "Bill..."
//
// ==> MDB slave to address the MDB master.
// Current implementation:
// - Card Reader to MDB master with calls like "Master..."  
// - Coin Acceptor to MSB master with calls like "MasterAcceptor..."
//
// ==> Executive master to address executive peripherals.
// Current implementation:
// - Executive to call peripherals like "VMC..."
//
// ==> Executive slave to address the executive master.
// Current implementation:
// - VMC to executive master with calls like "Executive..."
//---------------------------------------------------------

// History:
//---------
// 16.02.03 01.00 - Design and implementation of the "Acceptor..." calls.
// 01.04.03 01.01 - Design and implementation of the "Master..." calls.
// 22.04.03 01.10 - Design and implementation of the "VMC..." calls.
//				  - Design and implementation of the "Executive..." calls.
// 23.05.03 01.11 - Design and implementation of the "Bill..." calls.
// 02.06.03 01.20 - Design and implementation of the "Reader..." calls.
// 01.07.03 01.21 - Implementation of the overlapped methode for USB read.
//				  - Implementation of the GetLastError functionallity.
// 08.09.03 01.22 - Implementation of the multy device access.
// 14.12.03 01.30 - Implementation of the "MasterAcceptor..." calls.
// 15.03.04 01.31 - Modification: After reset and in idle state the BillType
//                  has a value of 0xFF, so it's possible to poll it.
// 21.04.04 01.32 - Function "ACCEPTOR_Dispense" corrected. 
//					Call to USB was missing.
//                - Function "ACCEPTOR_TubeStatus" new implemented.
// 06.09.04 01.33 - Corrected Bill Identification call, it didn't return to idle.
//				  - Several modifications for MDB bill acceptor.
// 17.09.04 01.34 - Executive master has send a vend command automatically if there
//					was enought credit. New the application must issue a vend command.
// 28.09.04 01.35 - Implemented a Sleep(3) in USBWrite for all devices.
//					In future versions, this must be implemented with events
//					to gain a professional solution.         
// 25.10.04 01.40 - Initialization procedure for each slave optimized. It initializes
//					the slave sequentially and not at the same time as before.
//					1. Card Reader, 2. Change giver, 3. Bill acceptor.
//				  - Timeout of slave polling function optimized.
//				  - Additional messages for the bill acceptor implemented.
// 15.01.05 01.41 - Executive Master: Synchronisation of command and response implemented
//					by sending command echo back and verification.
//					Note: The MDB/USB interface requires the latest firmware.
// 01.02.05 01.42 - Extension of the 'MASTER_SETUP' structure to fill in parameters
//                  required with MDB command 'READER_CONFIG_DATA'.
// 22.02.05 01.43 - Modified MDB slave to act as a level 1 device, 
//					according the parameters passed in MASTER_SETUP.
// 17.03.05 01.44 - Correcture of Vend Approved, bytes swaped.
// 01.04.05 01.45 - Changer function "AcceptorDiagnosticStatus" new implemented.
//				  - Message SS_ACCEPTOR_DIAG_STATUS added.
// 23.05.05 01.46 - Correcture in coin acceptor to improve coin acceptance.
// 07.06.05 01.50 - Correcture to terminate successfully with more then just one MDB device.
// 28.06.05 01.51 - Modification for NRI G46 device.
// 04.07.05 01.52 - Modification for bill acceptor CashCode MSM-3067EU8021
// 08.07.05 01.53 - Modification of function 'ReaderRevalueLimit' with additional parameter.
// 24.08.05 01.54 - Correcture with MasterCreate & ReaderCreate timeout, not to overwrite 
//                  the previous timeout.
//                - MDBDebug new implemented.
// 30.08.05 01.55 - Structure SLAVE_SETUP extented with fields of Expansion - RequestID.
// 03.11.05 01.56 - CPU load reduction for the MDB slave communication.
// 12.12.05 01.57 - MDBMaster: Reader cancel implemented.
//				  - MDBSlave: Cancelled implemented.
// 19.12.05 01.58 - Debug trace functionality new implemented.
// 20.01.06 01.59 - Problem solved where the MDBMaster stopped to poll the slaves.
//------------------------------------------------------------------------------------------
#define MDB_ENGINE_VERSION			0x0000013B

// DLL specific error code definition
//-----------------------------------
// The GetLastError() returns information on a function call failure.
// If bit #29 is set, then it is a MDBEngine specific error as defined below.
//---------------------------------------------------------------------------

// Create... was not called prior to this function call.
//------------------------------------------------------
#define DEVICE_NOT_CREATED			0x20000001

// Driver not accessible, retries expired.
//----------------------------------------
#define RETRY_COUNT_EXPIRED			0x20000002

// The specified buffer size exceeds the maximum buffer size.
//----------------------------------------------------------- 
#define BUFFER_SIZE_TOO_BIG			0x20000003

// Failed to allocate a new object because of insufficient memory.
//----------------------------------------------------------------
#define INSUFFICIENT_MEMORY			0x20000004 

// Device was already destroyed.
//------------------------------
#define NO_DEVICE_TO_DESTROY		0x20000005 

// Call is not allowed, the reader is not in a session.
//-----------------------------------------------------
#define READER_NOT_IN_SESSION		0x20000006

// The revalue limit value is not yet available.
//----------------------------------------------
#define REVALUE_LIMIT_NOT_AVAILABLE 0x20000007

// Function call is with this feature level not available.
//--------------------------------------------------------
#define FUNCTION_CALL_NOT_AVAILABLE 0x20000008

// DLL constants
//--------------
#define DOWNLOAD_ALL				0xFFFFFFFF
#define DOWNLOAD_DEFAULT			0

#pragma pack(push)
#pragma pack(1)

// Debug function definitions
//---------------------------
#define DBG_ALL_OFF			0x00000000
#define DBG_MASTER_TRACE	0x00000001
#define DBG_SLAVE_TRACE		0x00000002

typedef struct tag_VERSION_INFO
//=============================
{
	// MSB=Major version number, LSB=Minor version number
	//---------------------------------------------------
	DWORD dwVersion;

	// See definitions in MDBEngine.cpp
	//---------------------------------
	DWORD dwOptions;
}
VERSION_INFO;

typedef struct tag_MASTER_SETUP
//=============================
{
	LPARAM lParam;				// Parameter to pass with message lParam
								// Usually the 'this' of the receiving messages
	HWND  hParent;				// Handle of the parent window receiving messages
	DWORD dwDevice;				// USB device number (Default = 0)
	DWORD dwTimeout;			// Receiver inter character timeout (Default 2 ms) 
	DWORD dwFeatureLevel;		// Reader feature level to report to master
	DWORD dwCountryCode;		// Country code to report to master
	DWORD dwScalingFactor;		// Scaling factor to report to master
	DWORD dwDecimalPlaces;		// Decimal places to report to master
	DWORD dwMaximumResponseTime; // Maximum response time to report to master
	DWORD dwMiscellaneousOptions; // Miscellaneous options to report to master
	DWORD dwRevalueLimit;		// Revalue limit amount
	char  sManufacturer[MAX_MANUFACTURER+1]; // Manufacturer string to respond to master
	char  sSerialNumber[MAX_SERIAL_NUMBER+1]; // Serial Number to respond to master
	char  sModelNumber[MAX_MODEL_NUMBER+1];	// Model number to respond to master
	WORD  wVersion;				// Version to respond to master
}
MASTER_SETUP;

typedef struct tag_SLAVE_SETUP
//============================
// Note:
// dwMaxRetry:	Number of poll until next slave call retry.
// dwMaxFail:	Number of calls until quiet.
// With the defaults and no response it will call the slave 10 times
// (dwMaxFail) until quiet. Then it will retry every 10th call
// (dwMaxRetry) to check for a response.  
//------------------------------------------------------------------
{
	LPARAM lParam;				// Parameter to pass with message lParam
								// Usually the 'this' of the receiving messages
	HWND  hParent;				// Handle of the parent window receiving messages
	DWORD dwDevice;				// USB device number (Default 0)
	DWORD dwTimeout;			// Slave response timeout (Default 5 ms)
	DWORD dwInterval;			// Slave call interval (Default 100 ms)
	DWORD dwMaxRetry;			// Slave call retry count (Default 10)
	DWORD dwMaxFail;			// Slave call fail count (Default 10)
	DWORD dwFeatureLevel;		// Future level of MDB master
	DWORD dwScalingFactor;		// Scaling factor of MDB master
	DWORD dwDisplayColumns;		// Number of columns on display
	DWORD dwDisplayRows;		// Number of rows on display
	DWORD dwDisplayType;		// Display type
	DWORD dwMinimumPrice;		// Minimum price setting
	DWORD dwMaximumPrice;		// Maximum price setting
	char  sManufacturer[MAX_MANUFACTURER+1]; // Manufacturer string to respond to slave
	char  sSerialNumber[MAX_SERIAL_NUMBER+1]; // Serial Number to respond to slave
	char  sModelNumber[MAX_MODEL_NUMBER+1];	// Model number to respond to slave
	WORD  wVersion;				// Version to respond to slave
}
SLAVE_SETUP;

typedef struct tag_SLAVE_ACCEPTOR_SETUP
//=====================================
{
	LPARAM lParam;				// Parameter to pass with message lParam
								// Usually the 'this' of the receiving messages
	HWND  hParent;				// Handle of the parent window receiving messages
	DWORD dwDevice;				// USB device number (Default 0)
	DWORD dwTimeout;			// Slave response timeout (Default 5 ms)
	DWORD dwFeatureLevel;		// Future level
	DWORD dwCurrencyCode;		// Currency code
	DWORD dwScalingFactor;		// Scaling factor
	DWORD dwDecimalPlaces;		// Decimal places
	DWORD dwCoinTypeRouting;	// Coin type routing
	BYTE  CoinTypeCredit[16];	// Coin type credit
}
SLAVE_ACCEPTOR_SETUP;

typedef struct tag_EXECUTIVE_SETUP
//================================
{
	LPARAM lParam;				// Parameter to pass with message lParam
								// Usually the 'this' of the receiving messages
	HWND  hParent;				// Handle of the parent window receiving messages
	DWORD dwDevice;				// USB device number (Default = 0)
	DWORD dwTimeout;			// Receiver inter character timeout in milliseconds
	DWORD dwFactor;				// Scaling factor
	DWORD dwDecimals;			// Decimal point position
	DWORD dwVendTimeout;		// Wait for end of vend timeout in seconds
}
EXECUTIVE_SETUP;

typedef struct tag_VMC_SETUP
//==========================
{
	LPARAM lParam;				// Parameter to pass with message lParam
								// Usually the 'this' of the receiving messages
	HWND  hParent;				// Handle of the parent window receiving messages
	DWORD dwDevice;				// USB device number (Default = 0)
}
VMC_SETUP;

typedef struct tag_MASTER_INFO
//============================
// Used if PC is debit card reader with parameter of MDB master
//-------------------------------------------------------------
{
	DWORD dwFeatureLevel;		// Feature level
	DWORD dwColumns;			// Columns on display 
	DWORD dwRows;				// Rows on display
	DWORD dwInfo;				// Display info
	DWORD dwItemPrice;			// Item price (Valid after vend request)
	DWORD dwItemNumber;			// Item number (Valid after vend request)
	DWORD dwMinimumPrice;		// Acceptable minimum price
	DWORD dwMaximumPrice;		// Acceptable maximum price
	DWORD dwRevalueAmount;		// Amount of revalue request
	char  sManufacturer[MAX_MANUFACTURER+1];  // Manufacturer code 
	char  sSerialNumber[MAX_SERIAL_NUMBER+1]; // Serial number
	char  sModelNumber[MAX_MODEL_NUMBER+1];   // Model number
	WORD  wVersion;				// Software version 
}
MASTER_INFO;

typedef struct tag_READER_INFO
//============================
// Used if the PC is master with parameter of debit card reader
//-------------------------------------------------------------
{
	DWORD dwFeatureLevel;		// Feature level
	DWORD dwCountryCode;		// Country code
	DWORD dwScalingFactor;		// Scaling factor
	DWORD dwDecimalPlaces;		// Decimal places
	DWORD dwResponseTime;		// Maximum response time
	DWORD dwMiscOptions;		// Miscellaneous options
	DWORD dwOptionalFeatures;   // Optional feature bits
	char  sManufacturer[MAX_MANUFACTURER+1];  // Manufacturer code 
	char  sSerialNumber[MAX_SERIAL_NUMBER+1]; // Serial number
	char  sModelNumber[MAX_MODEL_NUMBER+1];   // Model number
	WORD  wVersion;				// Software version 
}
READER_INFO;

typedef struct tag_READER_SESSION
//===============================
{
	DWORD dwFunds;				// Available funds
	DWORD dwMediaID;            // Payment media identification number
	DWORD dwPaymentType;		// Payment type
	DWORD dwPaymentData;		// Payment data
	DWORD dwLanguage;			// User language code
	DWORD dwCurrency;			// User currency code
	DWORD dwOptions;			// Card options
}
READER_SESSION;

typedef struct tag_READER_REQUEST
//===============================
{
	DWORD dwItemPrice;
	DWORD dwItemNumber;
}
READER_REQUEST;

typedef struct tag_READER_APPROVED
//================================
{
	DWORD dwAmount;				// Vend amount
}
READER_APPROVED;

typedef struct tag_READER_DISPLAY
//===============================
{
	DWORD dwDisplayTime;					// Display time in milli seconds
	char  pDisplayData[MAX_DISPLAY_DATA];	// Display data to display
}
READER_DISPLAY;

typedef struct tag_ACCEPTOR_ENABLE
//================================
{
	DWORD dwAccepting;
	DWORD dwManually;
}
ACCEPTOR_ENABLE;

typedef struct tag_ACCEPTOR_INFO
//==============================
{
	DWORD dwChangerFeatureLevel;
	DWORD dwCountryCode;
	DWORD dwCoinScalingFactor;
	DWORD dwDecimalPlaces;
	DWORD dwCoinTypeRouting;
	DWORD dwSoftwareVersion;
	DWORD dwOptionalFeatures;
	BYTE  CoinTypeCredit[16];
	BYTE  TubeStatus[16];
	char  sManufacturerCode[MAX_MANUFACTURER+1];
	char  sSerialNumber[MAX_SERIAL_NUMBER+1];
	char  sModelRevision[MAX_MODEL_NUMBER+1];
}
ACCEPTOR_INFO;

typedef struct tag_BILL_INFO
//==========================
{
	DWORD dwBillFutureLevel;
	DWORD dwCurrencyCode;
	DWORD dwBillScalingFactor;
	DWORD dwDecimalPlaces;
	DWORD dwStackerCapacity;
	DWORD dwSecurityLevel;
	DWORD dwEscrowCapability;
	DWORD dwSoftwareVersion;								// Software version 
	DWORD dwOptionalFeatures;
	BYTE  BillTypeCredit[16];
	char  sManufacturer[MAX_MANUFACTURER+1];	// Manufacturer code 
	char  sSerialNumber[MAX_SERIAL_NUMBER+1];	// Serial number
	char  sModelRevision[MAX_MODEL_NUMBER+1];	// Model number
}
BILL_INFO;

typedef struct tag_BILL_STATUS
//============================
{
	DWORD dwBillType;
	DWORD dwBillRouting;
	DWORD dwBillStatus;
}
BILL_STATUS;

#pragma pack(pop)

typedef struct tag_DEVICE_SETUP
//=============================
{
	DWORD dwDevices;
	DWORD dwMasterTimeout;
	DWORD dwSlaveTimeout;
}
DEVICE_SETUP;

// Global MDB engine defines
//--------------------------
#define THREAD_EXIT_TIMEOUT			5000
#define TIMER_MDB					0
#define TIMER_EXECUTIVE				1

// Vend status defines
//--------------------
#define READER_VEND_CANCEL			0
#define READER_VEND_SUCCESS			1
#define READER_VEND_FAILURE			2

// MDB status messages, status in wParam
//--------------------------------------
#define WM_MASTER_STATUS			WM_USER+0x0800 // Master...
#define WM_ACCEPTOR_STATUS			WM_USER+0x0801 // Acceptor...
#define WM_VMC_STATUS				WM_USER+0x0802 // VMC...
#define WM_EXE_STATUS				WM_USER+0x0803 // Executive...
#define WM_BILL_STATUS				WM_USER+0x0804 // Bill...
#define WM_READER_STATUS			WM_USER+0x0805 // Reader...

// MDB master status (MS=Master status)
//-------------------------------------
#define MS_READER_ENABLE			0x0000
#define MS_READER_DISABLE			0x0001
#define MS_VEND_REQUEST				0x0002
#define MS_VEND_SUCCESS				0x0003
#define MS_VEND_FAILURE				0x0004
#define MS_REVALUE_REQUEST			0x0005
#define MS_READER_CANCELLED			0x0006
#define MS_FILE_RECEIVED			0x0007
#define MS_FILE_TRANSMIT			0x0008

// MDB debit card reader status SS=Slave status)
//----------------------------------------------
#define SS_READER_READY				0x0000
#define SS_READER_ENABLE			0x0001
#define SS_READER_DISABLE			0x0002
#define SS_READER_BEGIN_SESSION		0x0003
#define SS_READER_END_SESSION		0x0004
#define SS_READER_DISPLAY			0x0005	// Not implemented
#define SS_READER_APPROVED			0x0006
#define SS_READER_DENIED			0x0007
#define SS_READER_SUCCESS			0x0008
#define SS_READER_FAILURE			0x0009
#define SS_READER_REVALUE_APPROVED	0x000A
#define SS_READER_REVALUE_DENIED	0x000B
#define SS_READER_DISPLAY_REQUEST	0x000C
#define SS_READER_CANCEL			0x000D
#define SS_READER_FILE_RECEVIED		0x000E
#define SS_READER_FILE_TRANSMIT		0x000F

// MDB change giver status (SS=Slave status)
//------------------------------------------
#define SS_ACCEPTOR_READY			0x0000
#define SS_ACCEPTOR_FUNDS			0x0001
#define SS_ACCEPTOR_ESCROW			0x0002
#define SS_ACCEPTOR_RESET			0x0003
#define SS_ACCEPTOR_ERROR			0x0004
#define SS_ACCEPTOR_TUBE_STATUS     0x0005
#define SS_ACCEPTOR_DIAG_STATUS		0x0006

// MDB bill acceptor status (SS=Slave status)
//-------------------------------------------
#define SS_BILL_READY				0x0000
#define SS_BILL_STATUS				0x0001
#define SS_BILL_ESCROW				0x0002
#define SS_BILL_STACKED				0x0003
#define SS_BILL_RETURNED			0x0004
#define SS_BILL_REJECTED			0x0005
#define SS_BILL_RESET				0x0006

// EXE master status (MS=Master status)
//-------------------------------------
#define MS_EXE_READY				0x0000
#define MS_EXE_DISPLAY				0x0001
#define MS_EXE_SELECTION			0x0002
#define MS_EXE_SUCCESS				0x0003
#define MS_EXE_FAILURE				0x0004

// EXE VMC status (SS=Slave status)
//---------------------------------
#define SS_VMC_DISPLAY				0x0000
#define SS_VMC_VEND					0x0001

// Global variable declaration
//----------------------------
class CMDBMaster;
class CMDBSlave;
class CMDBDebug;
extern CMDBMaster* g_pMDBMaster;
extern CMDBSlave* g_pMDBSlave;
extern CMDBDebug* g_pMDBDebug;

// Exported USB interface calls
//-----------------------------
extern "C" BOOL WINAPI ResetTarget(DWORD dwDevice);
extern "C" BOOL WINAPI DownloadTarget(DWORD dwDevice=DOWNLOAD_ALL, DWORD dwRetries=10);
extern "C" BOOL WINAPI EngineVersion(VERSION_INFO* pInfo);
extern "C" BOOL WINAPI EngineReset();
extern "C" BOOL WINAPI GetDeviceCount(DWORD* pdwDevices);
extern "C" BOOL WINAPI GetDeviceID(DWORD dwDevice, DWORD* pdwID);
extern "C" BOOL WINAPI SetDeviceID(DWORD dwDevice, DWORD dwID);

// Exported MDB master calls, Debit System (Card Reader)
// The PC is MDB slave and calls the MDB master
//------------------------------------------------------
extern "C" BOOL WINAPI MasterCreate(MASTER_SETUP* pSetup);
extern "C" BOOL WINAPI MasterDestroy();
extern "C" BOOL WINAPI MasterReset();
extern "C" BOOL WINAPI MasterInfo(MASTER_INFO* pInfo);
extern "C" BOOL WINAPI MasterBeginSession(READER_SESSION* pSession);
extern "C" BOOL WINAPI MasterEndSession();
extern "C" BOOL WINAPI MasterApproved(READER_APPROVED* pApproved);
extern "C" BOOL WINAPI MasterDenied();
extern "C" BOOL WINAPI MasterRevalue(BOOL bRevalue);
extern "C" BOOL WINAPI MasterDisplay(READER_DISPLAY* pDisplay);
extern "C" BOOL WINAPI MasterReceiveFile(DWORD* pdwDevice, DWORD* pdwNumber, BYTE* pData, DWORD* pdwSize);
extern "C" BOOL WINAPI MasterTransmitFile(DWORD dwDevice, DWORD dwNumber, BYTE* pData, DWORD dwSize);

// Exported MDB slave calls, Debit System (Card Reader)
// The PC is MDB master and calls the MDB slave Debit Card Reader
//---------------------------------------------------------------
extern "C" BOOL WINAPI ReaderCreate(SLAVE_SETUP* pSetup);
extern "C" BOOL WINAPI ReaderDestroy();
extern "C" BOOL WINAPI ReaderReset();
extern "C" BOOL WINAPI ReaderEnable(BOOL bEnable);
extern "C" BOOL WINAPI ReaderInfo(READER_INFO* pInfo);
extern "C" BOOL WINAPI ReaderSession(READER_SESSION* pSession);
extern "C" BOOL WINAPI ReaderSessionComplete();
extern "C" BOOL WINAPI ReaderDisplay(READER_DISPLAY* pDisplay);
extern "C" BOOL WINAPI ReaderVendRequest(READER_REQUEST* pRequest);
extern "C" BOOL WINAPI ReaderVendStatus(DWORD dwStatus);
extern "C" BOOL WINAPI ReaderRevalueRequest(DWORD dwAmount);
extern "C" BOOL WINAPI ReaderRevalueLimit(DWORD* pdwLimit, BOOL bRequest=FALSE);
extern "C" BOOL WINAPI ReaderFeatureEnable(DWORD dwFeatures);
extern "C" BOOL WINAPI ReaderCancel();
extern "C" BOOL WINAPI ReaderReceiveFile(DWORD* pdwDevice, DWORD* pdwNumber, BYTE* pData, DWORD* pdwSize);
extern "C" BOOL WINAPI ReaderTransmitFile(DWORD dwDevice, DWORD dwNumber, BYTE* pData, DWORD dwSize);

// Exported MDB slave calls, Change Giver (Coin Acceptor)
// The PC is MDB master and calls the MDB slave Change Giver
//----------------------------------------------------------
extern "C" BOOL WINAPI AcceptorCreate(SLAVE_SETUP* pSetup);
extern "C" BOOL WINAPI AcceptorDestroy();
extern "C" BOOL WINAPI AcceptorReset();
extern "C" BOOL WINAPI AcceptorInfo(ACCEPTOR_INFO* pInfo);
extern "C" BOOL WINAPI AcceptorEnable(ACCEPTOR_ENABLE* pEnable);
extern "C" BOOL WINAPI AcceptorFunds(DWORD* pFunds);
extern "C" BOOL WINAPI AcceptorDeduct(DWORD dwAmount);
extern "C" BOOL WINAPI AcceptorRefund(DWORD dwAmount);
extern "C" BOOL WINAPI AcceptorDispense(DWORD dwCoinType, DWORD dwCoinCount);
extern "C" BOOL WINAPI AcceptorPayout();
extern "C" BOOL WINAPI AcceptorFeatureEnable(DWORD dwFeature);
extern "C" BOOL WINAPI AcceptorTubeStatus();
extern "C" BOOL WINAPI AcceptorDiagnosticStatus(ACCEPTOR_DIAGNOSTIC_STATUS* pDiagnosticStatus);

// Exportded MDB slave calls, Bill Acceptor
// The PC is MDB master and calls the MDB slave bill acceptor
//-----------------------------------------------------------
extern "C" BOOL WINAPI BillCreate(SLAVE_SETUP* pSetup);
extern "C" BOOL WINAPI BillDestroy();
extern "C" BOOL WINAPI BillReset();
extern "C" BOOL WINAPI BillInfo(BILL_INFO* pInfo);
extern "C" BOOL WINAPI BillEnable(DWORD dwEnable, DWORD dwEscrow);
extern "C" BOOL WINAPI BillEscrow(BOOL bEscrow);
extern "C" BOOL WINAPI BillStatus(BILL_STATUS* pBillStatus);
extern "C" BOOL WINAPI BillFeatureEnable(DWORD dwFeature);

// Exported executive slave calls, Venging Machine Controller (VMC)
// The PC is executive master and calls executive slave VMC
//-----------------------------------------------------------------
extern "C" BOOL WINAPI VMCCreate(EXECUTIVE_SETUP* pSetup);
extern "C" BOOL WINAPI VMCDestroy();
extern "C" BOOL WINAPI VMCDebug(EXECUTIVE_DEBUG* pDebug);
extern "C" BOOL WINAPI VMCCredit(DWORD dwCredit);
extern "C" BOOL WINAPI VMCVend();
extern "C" BOOL WINAPI VMCExactChange(BOOL bState);

// Exported executive master calls, Change Giver (Coin Acceptor)
// The PC is executive slave and calls the executive master Change Giver
//----------------------------------------------------------------------
extern "C" BOOL WINAPI ExecutiveCreate(VMC_SETUP* pSetup);
extern "C" BOOL WINAPI ExecutiveDestroy();
extern "C" BOOL WINAPI ExecutiveControl(DWORD dwControl);
extern "C" BOOL WINAPI ExecutivePrice(DWORD dwPrice);
extern "C" BOOL WINAPI ExecutiveVend(DWORD dwResult);
extern "C" BOOL WINAPI ExecutiveGetDisplay(VMC_DISPLAY* pDisplay);

// Exported MDB master calls, Change Giver (Coin acceptor)
// The PC is MDB slave and calls the MDB master
//--------------------------------------------------------
extern "C" BOOL WINAPI MasterAcceptorCreate(SLAVE_ACCEPTOR_SETUP* pSetup);
extern "C" BOOL WINAPI MasterAcceptorDestroy();
extern "C" BOOL WINAPI MasterAcceptorReset();
extern "C" BOOL WINAPI MasterAcceptorDeposit(DWORD dwRouting, DWORD dwCoinType);

// Exported debug calls
//---------------------
extern "C" BOOL WINAPI DebugCreate();
extern "C" BOOL WINAPI DebugDestroy();
extern "C" BOOL WINAPI DebugGetSetup(DWORD dwDevice, DEVICE_SETUP* pDeviceSetup);
extern "C" BOOL WINAPI DebugSetTrace(DWORD dwFlags, DWORD dwPort);

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately
// before the previous line.
//---------------------------------------------------------------------
#endif // !defined(AFX_MDBENGINE_H__D36C6134_7713_47CA_91D1_D9CD0CEC52EB__INCLUDED_)
